@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -111,6 +108,13 @@ int AB_Account_ReadDb(AB_ACCOUNT *a, GWEN_DB_NODE *db){
   else
     a->accountNumber=NULL;
 
+  free(a->subAccountId);
+  s=GWEN_DB_GetCharValue(db, "subAccountId", 0, NULL);
+  if (s)
+    a->subAccountId=strdup(s);
+  else
+    a->subAccountId=NULL;
+
   free(a->bankCode);
   s=GWEN_DB_GetCharValue(db, "bankCode", 0, NULL);
   if (s)
@@ -436,6 +440,7 @@ void AB_Account_SetSelectedUsers(AB_ACCOUNT *a, const AB_USER_LIST2 *ul) {
 	char numbuf[16];
 
 	snprintf(numbuf, sizeof(numbuf)-1, "%u", AB_User_GetUniqueId(u));
+        numbuf[sizeof(numbuf)-1]=0;
 	GWEN_StringList_AppendString(a->selectedUserIds, numbuf, 0, 1);
 	u=AB_User_List2Iterator_Next(it);
       }
@@ -480,6 +485,11 @@ int AB_Account_toDb(const AB_ACCOUNT *a, GWEN_DB_NODE *db){
   if (a->accountNumber)
     GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			 "accountNumber", a->accountNumber);
+
+  if (a->subAccountId)
+    GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                         "subAccountId", a->subAccountId);
+
   if (a->bankCode)
     GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			 "bankCode", a->bankCode);
@@ -521,7 +531,7 @@ int AB_Account_toDb(const AB_ACCOUNT *a, GWEN_DB_NODE *db){
   }
 
   GWEN_DB_DeleteVar(db, "selectedUser");
-  se=GWEN_StringList_FirstEntry(a->userIds);
+  se=GWEN_StringList_FirstEntry(a->selectedUserIds);
   while(se) {
     const char *s;
 
@@ -561,6 +571,7 @@ void AB_Account_free(AB_ACCOUNT *a){
       GWEN_INHERIT_FINI(AB_ACCOUNT, a);
       free(a->backendName);
 
+      free(a->subAccountId);
       free(a->accountNumber);
       free(a->bankCode);
       free(a->accountName);
@@ -657,6 +668,27 @@ void AB_Account_SetAccountNumber(AB_ACCOUNT *a, const char *s){
 
 
 
+const char *AB_Account_GetSubAccountId(const AB_ACCOUNT *a){
+  assert(a);
+  assert(a->usage);
+  return a->subAccountId;
+}
+
+
+
+void AB_Account_SetSubAccountId(AB_ACCOUNT *a, const char *s){
+  assert(a);
+  assert(a->usage);
+
+  free(a->subAccountId);
+  if (s)
+    a->subAccountId=strdup(s);
+  else
+    a->subAccountId=NULL;
+}
+
+
+
 const char *AB_Account_GetBankCode(const AB_ACCOUNT *a){
   assert(a);
   assert(a->usage);
