@@ -1236,6 +1236,7 @@ void GWENHYWFAR_CB AH_Job_Tan_FreeData(void *bp, void *p){
   free(aj->tanMediumId);
   free(aj->reference);
   free(aj->challenge);
+  free(aj->challengeHhd);
   GWEN_FREE_OBJECT(aj);
 }
 
@@ -1288,6 +1289,23 @@ int AH_Job_Tan_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
         aj->challenge=strdup(s);
       }
 
+      /* get special HHD challenge */
+      if (GWEN_DB_VariableExists(dbTanResponse, "challengeHHD")) {
+	const uint8_t *p;
+	unsigned int l;
+
+	p=GWEN_DB_GetBinValue(dbTanResponse, "challengeHHD", 0, NULL, 0, &l);
+	if (p && l) {
+	  GWEN_BUFFER *bbuf;
+
+	  bbuf=GWEN_Buffer_new(0, 256, 0, 1);
+	  GWEN_Text_ToHexBuffer((const char*) p, l, 0, 0, 0);
+	  free(aj->challengeHhd);
+	  aj->challengeHhd=strdup(GWEN_Buffer_GetStart(bbuf));
+	  GWEN_Buffer_free(bbuf);
+	}
+      }
+
       s=GWEN_DB_GetCharValue(dbTanResponse, "jobReference", 0, 0);
       if (s) {
         free(aj->reference);
@@ -1426,6 +1444,23 @@ void AH_Job_Tan_SetTanInfo(AH_JOB *j, const char *p) {
 
 
 
+void AH_Job_Tan_SetSegCode(AH_JOB *j, const char *p) {
+  AH_JOB_TAN *aj;
+  GWEN_DB_NODE *dbArgs;
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  dbArgs=AH_Job_GetArguments(j);
+  assert(dbArgs);
+
+  GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                       "segmentId", p);
+}
+
+
+
 const char *AH_Job_Tan_GetChallenge(const AH_JOB *j) {
   AH_JOB_TAN *aj;
 
@@ -1438,6 +1473,18 @@ const char *AH_Job_Tan_GetChallenge(const AH_JOB *j) {
 
 
 
+const char *AH_Job_Tan_GetHhdChallenge(const AH_JOB *j) {
+  AH_JOB_TAN *aj;
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  return aj->challengeHhd;
+}
+
+
+
 const char *AH_Job_Tan_GetReference(const AH_JOB *j) {
   AH_JOB_TAN *aj;
 
@@ -1470,6 +1517,60 @@ void AH_Job_Tan_SetTanMediumId(AH_JOB *j, const char *s) {
 
 
 
+void AH_Job_Tan_SetLocalAccountInfo(AH_JOB *j,
+                                    const char *bankCode,
+                                    const char *accountId,
+                                    const char *accountSubId) {
+  AH_JOB_TAN *aj;
+  GWEN_DB_NODE *dbArgs;
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  dbArgs=AH_Job_GetArguments(j);
+  assert(dbArgs);
+
+  if (bankCode && *bankCode)
+      GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                           "localAccount/bankCode", bankCode);
+  if (accountId && *accountId)
+      GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                           "localAccount/accountId", accountId);
+  if (accountSubId && *accountSubId)
+      GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                           "localAccount/accountSubId", accountSubId);
+}
+
+
+
+void AH_Job_Tan_SetSmsAccountInfo(AH_JOB *j,
+                                  const char *bankCode,
+                                  const char *accountId,
+                                  const char *accountSubId) {
+  AH_JOB_TAN *aj;
+  GWEN_DB_NODE *dbArgs;
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  dbArgs=AH_Job_GetArguments(j);
+  assert(dbArgs);
+
+  if (bankCode && *bankCode)
+      GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                           "smsAccount/bankCode", bankCode);
+  if (accountId && *accountId)
+      GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                           "smsAccount/accountId", accountId);
+  if (accountSubId && *accountSubId)
+      GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                           "smsAccount/accountSubId", accountSubId);
+}
+
+
+
 int AH_Job_Tan_FinishSetup(AH_JOB *j) {
   AH_JOB_TAN *aj;
   GWEN_DB_NODE *args;
