@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2011 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -160,6 +157,7 @@ void AH_Job_Tan_SetTanList(AH_JOB *j, const char *s);
 void AH_Job_Tan_SetTanInfo(AH_JOB *j, const char *p);
 
 const char *AH_Job_Tan_GetChallenge(const AH_JOB *j);
+const char *AH_Job_Tan_GetHhdChallenge(const AH_JOB *j);
 const char *AH_Job_Tan_GetReference(const AH_JOB *j);
 
 int AH_Job_Tan_GetTanMethod(const AH_JOB *j);
@@ -167,6 +165,17 @@ void AH_Job_Tan_SetTanMethod(AH_JOB *j, int i);
 
 void AH_Job_Tan_SetTanMediumId(AH_JOB *j, const char *s);
 
+void AH_Job_Tan_SetLocalAccountInfo(AH_JOB *j,
+                                    const char *bankCode,
+                                    const char *accountId,
+                                    const char *accountSubId);
+void AH_Job_Tan_SetSmsAccountInfo(AH_JOB *j,
+                                  const char *bankCode,
+                                  const char *accountId,
+                                  const char *accountSubId);
+
+void AH_Job_Tan_SetSegCode(AH_JOB *j, const char *p);
+
 int AH_Job_Tan_FinishSetup(AH_JOB *j);
 
 
