@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Thu Apr 29 2004
- copyright   : (C) 2004 by Martin Preuss
+ copyright   : (C) 2004-2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -21,7 +18,6 @@
 #include <gwenhywfar/text.h>
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/gwentime.h>
-#include <gwenhywfar/iolayer.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -535,7 +531,7 @@ int AHB_DTAUS__CreateSetC(GWEN_BUFFER *dst,
       return -1;
     }
     AB_Value_AddValue(sumDEM, val);
-    snprintf(buffer, sizeof(buffer), "%011.0lf", AB_Value_GetValueAsDouble(val)*100.0);
+    snprintf(buffer, sizeof(buffer), "%011.0f", AB_Value_GetValueAsDouble(val)*100.0);
     AB_Value_free(val);
     if (AHB_DTAUS__AddNum(dst, 11, buffer)) {
       DBG_ERROR(AQBANKING_LOGDOMAIN, "Error writing to buffer");
@@ -591,7 +587,7 @@ int AHB_DTAUS__CreateSetC(GWEN_BUFFER *dst,
       return -1;
     }
     AB_Value_AddValue(sumEUR, val);
-    snprintf(buffer, sizeof(buffer), "%011.0lf", AB_Value_GetValueAsDouble(val)*100.0);
+    snprintf(buffer, sizeof(buffer), "%011.0f", AB_Value_GetValueAsDouble(val)*100.0);
     AB_Value_free(val);
     if (AHB_DTAUS__AddNum(dst, 11, buffer)) {
       DBG_ERROR(AQBANKING_LOGDOMAIN, "Error writing to buffer");
@@ -772,7 +768,7 @@ int AHB_DTAUS__CreateSetE(GWEN_BUFFER *dst,
   }
 
   /* field 5: sum of DEM values */
-  snprintf(buffer, sizeof(buffer), "%013.0lf",
+  snprintf(buffer, sizeof(buffer), "%013.0f",
 	   AB_Value_GetValueAsDouble(sumDEM)*100.0);
   if (AHB_DTAUS__AddNum(dst, 13, buffer)) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Error writing to buffer");
@@ -780,7 +776,7 @@ int AHB_DTAUS__CreateSetE(GWEN_BUFFER *dst,
   }
 
   /* field 6: sum of peer account ids */
-  snprintf(buffer, sizeof(buffer), "%017.0lf",
+  snprintf(buffer, sizeof(buffer), "%017.0f",
 	   AB_Value_GetValueAsDouble(sumAccountIds));
   if (AHB_DTAUS__AddNum(dst, 17, buffer)) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Error writing to buffer");
@@ -788,7 +784,7 @@ int AHB_DTAUS__CreateSetE(GWEN_BUFFER *dst,
   }
 
   /* field 7: sum of peer bank codes */
-  snprintf(buffer, sizeof(buffer), "%017.0lf",
+  snprintf(buffer, sizeof(buffer), "%017.0f",
 	   AB_Value_GetValueAsDouble(sumBankCodes));
   if (AHB_DTAUS__AddNum(dst, 17, buffer)) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Error writing to buffer");
@@ -796,7 +792,7 @@ int AHB_DTAUS__CreateSetE(GWEN_BUFFER *dst,
   }
 
   /* field 8: sum of EUR values */
-  snprintf(buffer, sizeof(buffer), "%013.0lf",
+  snprintf(buffer, sizeof(buffer), "%013.0f",
 	   AB_Value_GetValueAsDouble(sumEUR)*100.0);
   if (AHB_DTAUS__AddNum(dst, 13, buffer)) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Error writing to buffer");
@@ -812,12 +808,10 @@ int AHB_DTAUS__CreateSetE(GWEN_BUFFER *dst,
 
 
 int AHB_DTAUS__Export(GWEN_DBIO *dbio,
-		      GWEN_IO_LAYER *io,
+		      GWEN_SYNCIO *sio,
                       GWEN_DB_NODE *data,
 		      GWEN_DB_NODE *cfg,
-		      uint32_t flags,
-		      uint32_t guiid,
-		      int msecs){
+		      uint32_t flags){
   AB_VALUE *sumEUR;
   AB_VALUE *sumDEM;
   AB_VALUE *sumBankCodes;
@@ -829,7 +823,7 @@ int AHB_DTAUS__Export(GWEN_DBIO *dbio,
   int isEuro;
   const uint8_t *p;
   uint32_t size;
-  uint32_t bytesWritten;
+  int rv;
 
   isDebitNote=(strcasecmp(GWEN_DB_GetCharValue(cfg, "type", 0, "transfer"),
                           "debitnote")==0);
@@ -869,7 +863,7 @@ int AHB_DTAUS__Export(GWEN_DBIO *dbio,
 				sumEUR, sumDEM,
 				sumBankCodes, sumAccountIds)) {
         DBG_ERROR(AQBANKING_LOGDOMAIN, "Error creating C set from this data:");
-        GWEN_DB_Dump(gr, stderr, 2);
+        GWEN_DB_Dump(gr, 2);
         GWEN_Buffer_free(dst);
 	AB_Value_free(sumAccountIds);
 	AB_Value_free(sumBankCodes);
@@ -907,29 +901,13 @@ int AHB_DTAUS__Export(GWEN_DBIO *dbio,
   /* DTAUS finished, write it */
   p=(const uint8_t*)GWEN_Buffer_GetStart(dst);
   size=GWEN_Buffer_GetUsedBytes(dst);
-  bytesWritten=0;
-  while(bytesWritten<size) {
-    int err;
-    unsigned int bsize;
-
-    bsize=size-bytesWritten;
-    err=GWEN_Io_Layer_WriteBytes(io, p, bsize,
-				 GWEN_IO_REQUEST_FLAGS_WRITEALL |
-				 GWEN_IO_REQUEST_FLAGS_FLUSH,
-				 guiid, msecs);
-    if (err<0) {
-      DBG_ERROR_ERR(AQBANKING_LOGDOMAIN, err);
-      GWEN_Buffer_free(dst);
-      return err;
-    }
-    if (bsize==0) {
-      DBG_ERROR(AQBANKING_LOGDOMAIN, "Broken pipe");
-      GWEN_Buffer_free(dst);
-      return GWEN_ERROR_IO;
-    }
-    p+=bsize;
-    bytesWritten+=bsize;
-  } /* while */
+  rv=GWEN_SyncIo_WriteForced(sio, p, size);
+  if (rv<0) {
+    DBG_ERROR(AQBANKING_LOGDOMAIN, "Broken pipe");
+    GWEN_Buffer_free(dst);
+    return GWEN_ERROR_IO;
+  }
+  GWEN_Buffer_free(dst);
 
   return 0;
 }
